"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AptosWormholeCore = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const connect_sdk_aptos_1 = require("@wormhole-foundation/connect-sdk-aptos");
class AptosWormholeCore {
    network;
    chain;
    connection;
    contracts;
    chainId;
    coreBridge;
    constructor(network, chain, connection, contracts) {
        this.network = network;
        this.chain = chain;
        this.connection = connection;
        this.contracts = contracts;
        this.chainId = (0, connect_sdk_1.toChainId)(chain);
        const coreBridgeAddress = contracts.coreBridge;
        if (!coreBridgeAddress)
            throw new Error(`CoreBridge contract Address for chain ${chain} not found`);
        this.coreBridge = coreBridgeAddress;
    }
    getMessageFee() {
        throw new Error("Method not implemented.");
    }
    static async fromRpc(connection, config) {
        const [network, chain] = await connect_sdk_aptos_1.AptosPlatform.chainFromRpc(connection);
        const conf = config[chain];
        if (conf.network !== network)
            throw new Error(`Network mismatch: ${conf.network} !== ${network}`);
        return new AptosWormholeCore(network, chain, connection, conf.contracts);
    }
    async *publishMessage(sender, message) {
        throw new Error("Method not implemented.");
    }
    async *verifyMessage(sender, vaa) {
        throw new Error("Not implemented.");
    }
    async parseTransaction(txid) {
        const transaction = await this.connection.getTransactionByHash(txid);
        if (transaction.type !== "user_transaction")
            throw new Error(`${txid} is not a user_transaction`);
        const userTransaction = transaction;
        const message = userTransaction.events.find((event) => event.type.endsWith("WormholeMessage"));
        if (!message || !message.data) {
            throw new Error(`WormholeMessage not found for ${txid}`);
        }
        const { sender, sequence } = message.data;
        // TODO: make this work for address
        const emitter = new connect_sdk_1.UniversalAddress(BigInt(sender).toString(16).padStart(64, "0"));
        return [{ chain: this.chain, emitter, sequence: BigInt(sequence) }];
    }
}
exports.AptosWormholeCore = AptosWormholeCore;
//# sourceMappingURL=core.js.map